==> digikam_7.9.0.orig.tar.xz: digikam-7.9.0/core/dplugins/editor/colors/bwsepia/bwsepiatoolplugin.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2018-07-30
 * Description : image editor plugin to convert to Black and White
 *
 * Copyright (C) 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_BWSEPIATOOL_PLUGIN_H
#define DIGIKAM_BWSEPIATOOL_PLUGIN_H

// Local includes

#include "dplugineditor.h"

#define DPLUGIN_IID "org.kde.digikam.plugin.editor.BWSepiaTool"

using namespace Digikam;

namespace DigikamEditorBWSepiaToolPlugin
{

class BWSepiaToolPlugin : public DPluginEditor
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID DPLUGIN_IID)
    Q_INTERFACES(Digikam::DPluginEditor)

public:

    explicit BWSepiaToolPlugin(QObject* const parent = nullptr);
    ~BWSepiaToolPlugin()                 override;

    QString name()                 const override;
    QString iid()                  const override;
    QIcon   icon()                 const override;
    QString details()              const override;
    QString description()          const override;
    QList<DPluginAuthor> authors() const override;

    void setup(QObject* const)           override;

private Q_SLOTS:

    void slotBWSepia();
};

} // namespace DigikamEditorBWSepiaToolPlugin

#endif // DIGIKAM_BWSEPIATOOL_PLUGIN_H

==> digikam_8.1.0.orig.tar.xz: digikam-8.1.0/core/dplugins/editor/colors/bwsepia/bwsepiatoolplugin.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2018-07-30
 * Description : image editor plugin to convert to Black and White
 *
 * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#ifndef DIGIKAM_BWSEPIATOOL_PLUGIN_H
#define DIGIKAM_BWSEPIATOOL_PLUGIN_H

// Local includes

#include "dplugineditor.h"

#define DPLUGIN_IID "org.kde.digikam.plugin.editor.BWSepiaTool"

using namespace Digikam;

namespace DigikamEditorBWSepiaToolPlugin
{

class BWSepiaToolPlugin : public DPluginEditor
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID DPLUGIN_IID)
    Q_INTERFACES(Digikam::DPluginEditor)

public:

    explicit BWSepiaToolPlugin(QObject* const parent = nullptr);
    ~BWSepiaToolPlugin()                 override;

    QString name()                 const override;
    QString iid()                  const override;
    QIcon   icon()                 const override;
    QString details()              const override;
    QString description()          const override;
    QList<DPluginAuthor> authors() const override;
    QString handbookSection()      const override;
    QString handbookChapter()      const override;
    QString handbookReference()    const override;

    void setup(QObject* const)           override;

private Q_SLOTS:

    void slotBWSepia();
};

} // namespace DigikamEditorBWSepiaToolPlugin

#endif // DIGIKAM_BWSEPIATOOL_PLUGIN_H
